#!/usr/bin/perl
use strict; use warnings; use Getopt::Long;
use Bio::Seq; use Bio::SeqIO;

#- INITIALIZE ---------------------------------------------------------------#

my $fasta = "../annotations/aedes_albopictus_LA_20200616.nixsplit.fa";
my $output = "../annotations/aedes_albopictus_LA2_20200826.fa";
my $trans = "../contig_info/position_translator_2.txt";
my $help;

GetOptions ('f:s'       => \$fasta,
            't:s'       => \$trans,
            'o:s'       => \$output,
            'help|h'    => \$help);
if ($help) {die "
This is a one-time script that renames scaffold names after adding the Nix
scaffold to chromosome 1.

  -f path to the input fasta-format genome.
  -t path to the translation file.
  -o path to the output fasta-format genome.
  -h display this message.\n\n"}

open (my $tr, '<', $trans) or die "
Could not open the input translation file '$trans'.\n";
open (my $out, '>', $output) or die "
Could not open the output file '$output'.\n";

#- READ IN TRANSLATION FILE -------------------------------------------------#

<$tr>; #remove header

my %t;

while (<$tr>) {
  chomp;
  my @line = split;
  unless ($line[6] =~ m/^chr\d\.\d+$/ or $line[6] eq "Nix_scaffold") {die "
Could not parse the pseudo-scaffold name on the following line:\n$_\n"}
  $t{$line[6]}{'chromosome'} = $line[3];
  unless ($line[3] =~ m/^\d+$/) {die "
Could not parse the true chromosome number on the following line:\n$_\n"}
  $t{$line[6]}{'scaffold'} = $line[4];
  unless ($line[4] =~ m/^\d+$/) {die "
Could not parse the true scaffold number on the following line:\n$_\n"}
  $t{$line[6]}{'reversed'} = $line[7];
  unless ($line[7] =~ m/^[01]$/) {die "
Could not parse the reversed-status on the following line:\n$_\n"}
}

close $tr;

#- FILTER GENOME ------------------------------------------------------------#

my $fa = Bio::SeqIO->new(-file => "$fasta", -format => "fasta");

while (my $record = $fa->next_seq) {
  my $name = $record->display_id;
  unless (exists $t{$name}) {die "
Could not find the following scaffold in the translation file: '$name'\n"}
  print $out ">chr$t{$name}{'chromosome'}.$t{$name}{'scaffold'}\n";
  if ($t{$name}{'reversed'} == 1) {
#    my $seq = $record->seq;
    my $revcomp = $record->revcom->seq;
    print $out "$revcomp\n"
  } else {
    my $seq = $record->seq;
    print $out "$seq\n"
  }
}

#- TIDY UP ------------------------------------------------------------------#

close $out;

#- FIN ----------------------------------------------------------------------#