#!/usr/bin/perl
use strict; use warnings; use Getopt::Long;

#- INITIALIZE ---------------------------------------------------------------#

my $annotation = "../annotations/aedes_albopictus_LA_20200616.gff3";
my $output = "../annotations/aedes_albopictus_LA2_20200826.gff3";
my $trans = "../contig_info/position_translator_2.txt";
my $help;

GetOptions ('f:s'       => \$annotation,
            't:s'       => \$trans,
            'o:s'       => \$output,
            'help|h'    => \$help);
if ($help) {die "
This is a one-time script that redoes the annotation to take into account
that we moved the nix scaffold to chromosome 1.

  -f path to the input annotation.
  -t path to the translation file.
  -o path to the output annotation.
  -h display this message.\n\n"}

open (my $tr, '<', $trans) or die "
Could not open the input translation file '$trans'.\n";
open (my $in, '<', $annotation) or die "
Could not open the input annotation file '$annotation'.\n";
open (my $out, '>', $output) or die "
Could not open the output file '$output'.\n";

#- READ IN TRANSLATION FILE -------------------------------------------------#

<$tr>; #remove header

my %t;

while (<$tr>) {
  chomp;
  my @line = split;
  unless ($line[6] =~ m/^chr\d\.\d+$/ or $line[6] eq "Nix_scaffold") {die "
Could not parse the pseudo-scaffold name on the following line:\n$_\n"}
  $t{$line[6]}{'chromosome'} = $line[3];
  unless ($line[3] =~ m/^\d+$/) {die "
Could not parse the true chromosome number on the following line:\n$_\n"}
  $t{$line[6]}{'scaffold'} = $line[4];
  unless ($line[4] =~ m/^\d+$/) {die "
Could not parse the true scaffold number on the following line:\n$_\n"}
  $t{$line[6]}{'reversed'} = $line[7];
  unless ($line[7] =~ m/^[01]$/) {die "
Could not parse the reversed-status on the following line:\n$_\n"}
}

close $tr;

#- ADJUST ANNOTATION --------------------------------------------------------#

while (<$in>) {
  chomp;
  my @line = split ("\t", $_);
  if ($line[0] eq "chr3.129") {
    if ($line[4] <= 2255968) {
      print $out "$_\n"
    } else {
      if ($line[3] > 2255968) {
        $line[0] = "chr1.86";
        $line[3] -= 2255968;
        $line[4] -= 2255968;
        my $newline = join ("\t", @line);
        print $out "$newline\n"
      } else {
        print STDOUT "Skipping one annotation found across the cut boundary: \n$_\n"
      }
    }
  } else {
    $line[0] = "chr" . $t{$line[0]}{'chromosome'} . "." . $t{$line[0]}{'scaffold'};
    my $newline = join ("\t", @line);
    print $out "$newline\n"
  }
}

#- TIDY UP ------------------------------------------------------------------#

close $in; close $out;

#- FIN ----------------------------------------------------------------------#